@@ -44,7 +44,31 @@ build_copy_data <- function(dm, dest, table_names, set_key_constraints, con) {
 
     pks_clause <-
       pks %>%
-      mutate(sql = map_chr(pk_col, ~ paste(DBI::dbQuoteIdentifier(con, .x), collapse = ", ")))
+      mutate(
+        cols = map_chr(pk_col, ~ paste(DBI::dbQuoteIdentifier(con, .x), collapse = ", ")),
+        constraint = "PRIMARY KEY"
+      )
+
+    fks <-
+      dm_get_all_fks_impl(dm) %>%
+      rename(source_name = child_table)
+
+    unique_clause <-
+      fks %>%
+      select(source_name = parent_table, pk_col = parent_key_cols) %>%
+      anti_join(pks, by = c("source_name", "pk_col")) %>%
+      distinct() %>%
+      mutate(
+        cols = map_chr(pk_col, ~ paste(DBI::dbQuoteIdentifier(con, .x), collapse = ", ")),
+        constraint = "UNIQUE"
+      )
+
+    clause <-
+      bind_rows(pks_clause, unique_clause) %>%
+      mutate(sql = paste0(",\n", constraint, " (", cols, ")")) %>%
+      group_by(source_name) %>%
+      summarize(sql = paste(sql, collapse = "")) %>%
+      ungroup()
 
     pks_flat <-
       pks %>%
@@ -53,10 +77,6 @@ build_copy_data <- function(dm, dest, table_names, set_key_constraints, con) {
       summarize(column = as.character(unlist(pk_col)), pk = TRUE) %>%
       ungroup()
 
-    fks <-
-      dm_get_all_fks_impl(dm) %>%
-      select(source_name = child_table, child_fk_cols)
-
     # Need to supply NOT NULL modifiers for primary keys
     # because they are difficult to add to MSSQL after the fact
     copy_data_types <-
@@ -68,18 +88,18 @@ build_copy_data <- function(dm, dest, table_names, set_key_constraints, con) {
       unnest(c(column, type)) %>%
       left_join(pks_flat, by = c("source_name", "column")) %>%
       mutate(full_type = paste0(type, if_else(pk, " NOT NULL", "", ""))) %>%
-
-      left_join(pks_clause, by = "source_name") %>%
+      #
+      left_join(clause, by = "source_name") %>%
       group_by(source_name) %>%
-
+      #
       # HACK: Append PRIMARY KEY clause to end, https://github.com/r-dbi/DBI/pull/351
       # So far this is the only reason to use `con` in this function
       mutate(full_type = paste0(full_type, if_else(
         !!set_key_constraints & !is.na(sql) & (row_number() == n()),
-        paste0(", PRIMARY KEY (", sql, ")"),
+        sql,
         ""
       ))) %>%
-
+      #
       summarize(types = list(deframe(tibble(column, full_type))))
 
     copy_data_unique_indexes <-
@@ -136,7 +156,7 @@ queries_set_fk_relations <- function(dest, fk_information) {
   db_child_tables <- fk_information$db_child_table
   child_fk_cols <- fk_information$child_fk_cols
   db_parent_tables <- fk_information$db_parent_table
-  parent_pk_col <- fk_information$pk_col
+  parent_pk_col <- fk_information$parent_key_cols
 
   if (is_mssql(dest) || is_postgres(dest)) {
     pmap_chr(
@@ -299,11 +319,12 @@ dbname_mssql <- function(con, dbname) {
 get_names_table_mssql <- function(con, dbname_sql) {
   tbl(
     con,
-    sql(glue::glue("SELECT tabs.name AS table_name, schemas.name AS schema_name
+    sql(glue::glue("
+      SELECT tabs.name AS table_name, schemas.name AS schema_name
       FROM {dbname_sql}sys.tables tabs
       INNER JOIN {dbname_sql}sys.schemas schemas ON
-      tabs.schema_id = schemas.schema_id"
-    ))
+      tabs.schema_id = schemas.schema_id
+    "))
   )
 }
 
