@@ -139,7 +139,8 @@ dm_flatten_to_tbl_impl <- function(dm, start, ..., join, join_name, squash) {
   order_df <- left_join(tibble(name = unname(list_of_pts)), order_df, by = "name")
 
   # list of join partners
-  ordered_table_list <- prep_dm %>%
+  ordered_table_list <-
+    prep_dm %>%
     dm_get_tables() %>%
     extract(order_df$name)
   by <- map2(order_df$pred, order_df$name, ~ get_by(prep_dm, .x, .y))
@@ -216,8 +217,7 @@ parent_child_table <- function(dm, table_1, table_2) {
   rel
 }
 
-check_flatten_to_tbl <- function(
-                                 join_name,
+check_flatten_to_tbl <- function(join_name,
                                  part_cond_abort_filters,
                                  any_not_reachable,
                                  g,
