@@ -14,6 +14,6 @@ register_pkgdown_methods <- function() {
 
   stopifnot(rlang::is_installed(c("DiagrammeR", "DiagrammeRsvg")))
   # For dev pkgdown
-  vctrs::s3_register("downlit::replay_html", "dm_draw", replay_html_dm_draw)
-  vctrs::s3_register("pkgdown::pkgdown_print", "grViz", pkgdown_print_grViz)
+  s3_register("downlit::replay_html", "dm_draw", replay_html_dm_draw)
+  s3_register("pkgdown::pkgdown_print", "grViz", pkgdown_print_grViz)
 }
