@@ -171,21 +171,35 @@ tf_1 %<-% tibble(
   b = LETTERS[1:10]
 )
 
-tf_2 %<-% tibble(
+tf_2_simple %<-% tibble(
   c = c("elephant", "lion", "seal", "worm", "dog", "cat"),
   d = 2:7,
   e = c(LETTERS[4:7], LETTERS[5:6])
 )
 
-tf_3 %<-% tibble(
+tf_2 %<-% tibble(
+  c = c("elephant", "lion", "seal", "worm", "dog", "cat"),
+  d = 2:7,
+  e = c(LETTERS[4:7], LETTERS[5:6]),
+  e1 = c(4:7, 5:6),
+)
+
+tf_3_simple %<-% tibble(
   f = LETTERS[2:11],
   g = c("one", "two", "three", "four", "five", "six", "seven", "eight", "nine", "ten")
 )
 
+tf_3 %<-% tibble(
+  f = LETTERS[c(3, 3:11)],
+  f1 = c(2:7, 7L, 7L, 10:11),
+  g = c("one", "two", "three", "four", "five", "six", "seven", "eight", "nine", "ten")
+)
+
 tf_4 %<-% tibble(
   h = letters[1:5],
   i = c("three", "four", "five", "six", "seven"),
-  j = c(LETTERS[3:6], LETTERS[6])
+  j = c(LETTERS[3:6], LETTERS[6]),
+  j1 = c(3:6, 6L),
 )
 
 tf_5 %<-% tibble(
@@ -209,19 +223,24 @@ dm_for_filter_w_cycle %<-% {
     tf_1 = tf_1(), tf_2 = tf_2(), tf_3 = tf_3(), tf_4 = tf_4(), tf_5 = tf_5(), tf_6 = tf_6(), tf_7 = tf_7()
   ) %>%
     dm_add_pk(tf_1, a) %>%
+    dm_add_pk(tf_3, c(f, f1)) %>%
+    #
     dm_add_pk(tf_2, c) %>%
-    dm_add_pk(tf_3, f) %>%
-    dm_add_pk(tf_4, h) %>%
-    dm_add_pk(tf_5, k) %>%
-    dm_add_pk(tf_6, n) %>%
-    dm_add_pk(tf_7, p) %>%
     dm_add_fk(tf_2, d, tf_1) %>%
-    dm_add_fk(tf_2, e, tf_3) %>%
-    dm_add_fk(tf_4, j, tf_3) %>%
-    dm_add_fk(tf_5, l, tf_4) %>%
-    dm_add_fk(tf_5, m, tf_6) %>%
+    dm_add_fk(tf_2, c(e, e1), tf_3) %>%
+    #
+    dm_add_pk(tf_4, h) %>%
+    dm_add_fk(tf_4, c(j, j1), tf_3) %>%
+    #
+    dm_add_pk(tf_7, p) %>%
+    dm_add_fk(tf_7, q, tf_2) %>%
+    #
+    dm_add_pk(tf_6, o) %>%
     dm_add_fk(tf_6, o, tf_7) %>%
-    dm_add_fk(tf_7, q, tf_2)
+    #
+    dm_add_pk(tf_5, k) %>%
+    dm_add_fk(tf_5, l, tf_4) %>%
+    dm_add_fk(tf_5, m, tf_6, n)
 }
 
 dm_for_filter %<-% {
@@ -231,59 +250,33 @@ dm_for_filter %<-% {
 
 dm_for_filter_sqlite %<--% copy_dm_to(sqlite(), dm_for_filter())
 
-output_1 %<-% list(
-  tf_1 = tibble(a = c(4:7), b = LETTERS[4:7]),
-  tf_2 = tibble(c = c("seal", "worm", "dog", "cat"), d = 4:7, e = c("F", "G", "E", "F")),
-  tf_3 = tibble(f = LETTERS[5:7], g = c("four", "five", "six")),
-  tf_4 = tibble(h = letters[3:5], i = c("five", "six", "seven"), j = c("E", "F", "F")),
-  tf_5 = tibble(
-    k = 2:4,
-    l = letters[3:5],
-    m = c("tree", "streetlamp", "streetlamp")
-  ),
-  tf_6 = tibble(
-    n = c("tree", "streetlamp"),
-    o = c("f", "h")
-  )
-)
-
-output_3 %<-% list(
-  tf_1 = tibble::tribble(
-    ~a, ~b,
-    4L, "D",
-    7L, "G"
-  ),
-  tf_2 = tibble::tribble(
-    ~c, ~d, ~e,
-    "seal", 4L, "F",
-    "cat", 7L, "F"
-  ),
-  tf_3 = tibble::tribble(
-    ~f, ~g,
-    "F", "five"
-  ),
-  tf_4 = tibble::tribble(
-    ~h, ~i, ~j,
-    "d", "six", "F",
-    "e", "seven", "F"
-  ),
-  tf_5 = tibble::tribble(
-    ~k, ~l, ~m,
-    3L, "d", "streetlamp",
-    4L, "e", "streetlamp"
-  ),
-  tf_6 = tibble::tribble(
-    ~n, ~o,
-    "streetlamp", "h"
-  )
-)
-
-
 dm_for_filter_rev %<-% {
   def_dm_for_filter <- dm_get_def(dm_for_filter())
   new_dm3(def_dm_for_filter[rev(seq_len(nrow(def_dm_for_filter))), ])
 }
 
+# Deprecated tests
+dm_for_filter_simple %<-% {
+  dm(
+    tf_1 = tf_1(), tf_2 = tf_2_simple(), tf_3 = tf_3_simple(), tf_4 = tf_4(), tf_5 = tf_5(), tf_6 = tf_6()
+  ) %>%
+    dm_add_pk(tf_1, a) %>%
+    dm_add_pk(tf_3, f) %>%
+    #
+    dm_add_pk(tf_2, c) %>%
+    dm_add_fk(tf_2, d, tf_1) %>%
+    dm_add_fk(tf_2, e, tf_3) %>%
+    #
+    dm_add_pk(tf_4, h) %>%
+    dm_add_fk(tf_4, j, tf_3) %>%
+    #
+    dm_add_pk(tf_6, n) %>%
+    #
+    dm_add_pk(tf_5, k) %>%
+    dm_add_fk(tf_5, l, tf_4) %>%
+    dm_add_fk(tf_5, m, tf_6)
+}
+
 # for tests on `dm` objects: dm_add_pk(), dm_add_fk() ------------------------
 
 dm_test_obj %<-% as_dm(list(
@@ -310,7 +303,7 @@ rows_dm_obj <- 36L
 
 dm_more_complex_part %<-% {
   dm(
-    tf_6_2 = tibble(p = letters[1:6], f = LETTERS[6:11]),
+    tf_6_2 = tibble(p = letters[1:6], f = LETTERS[6:11], f1 = c(6:7, 7L, 7L, 10:11)),
     tf_4_2 = tibble(
       r = letters[2:6],
       s = c("three", "five", "six", "seven", "eight"),
@@ -331,7 +324,7 @@ dm_more_complex %<-% {
   ) %>%
     dm_add_pk(tf_1, a) %>%
     dm_add_pk(tf_2, c) %>%
-    dm_add_pk(tf_3, f) %>%
+    dm_add_pk(tf_3, c(f, f1)) %>%
     dm_add_pk(tf_4, h) %>%
     dm_add_pk(tf_4_2, r) %>%
     dm_add_pk(tf_5, k) %>%
@@ -343,12 +336,12 @@ dm_more_complex %<-% {
     dm_add_pk(d, d_1) %>%
     dm_add_pk(e, e_1) %>%
     dm_add_fk(tf_2, d, tf_1) %>%
-    dm_add_fk(tf_2, e, tf_3) %>%
-    dm_add_fk(tf_4, j, tf_3) %>%
+    dm_add_fk(tf_2, c(e, e1), tf_3) %>%
+    dm_add_fk(tf_4, c(j, j1), tf_3) %>%
     dm_add_fk(tf_5, l, tf_4) %>%
     dm_add_fk(tf_5, l, tf_4_2) %>%
     dm_add_fk(tf_5, m, tf_6) %>%
-    dm_add_fk(tf_6_2, f, tf_3) %>%
+    dm_add_fk(tf_6_2, c(f, f1), tf_3) %>%
     dm_add_fk(b, b_2, a) %>%
     dm_add_fk(b, b_3, c) %>%
     dm_add_fk(d, b_1, b) %>%
@@ -358,7 +351,8 @@ dm_more_complex %<-% {
 # for testing `dm_disambiguate_cols()` ----------------------------------------
 
 iris_1 %<-% {
-  as_tibble(iris) %>%
+  datasets::iris %>%
+    as_tibble() %>%
     mutate(key = row_number()) %>%
     select(key, everything())
 }
@@ -385,7 +379,8 @@ iris_3_dis %<-% {
 }
 
 dm_for_disambiguate %<-% {
-  as_dm(list(iris_1 = iris_1(), iris_2 = iris_2(), iris_3 = iris_3())) %>%
+  list(iris_1 = iris_1(), iris_2 = iris_2(), iris_3 = iris_3()) %>%
+    as_dm() %>%
     dm_add_pk(iris_1, key) %>%
     dm_add_fk(iris_2, key, iris_1)
 }
@@ -503,13 +498,7 @@ bad_dm %<--% {
 }
 
 dm_nycflights_small_base %<-% {
-  airlines <- nycflights13::airlines
-  airports <- nycflights13::airports
-  planes <- nycflights13::planes
-  flights <- flights_subset()
-  weather <- weather_subset()
-
-  dm(airlines, airports, flights, planes, weather)
+  dm(!!!dm_get_tables(dm_nycflights13()))
 }
 
 # Do not add PK and FK constraints to the database
@@ -546,7 +535,8 @@ get_test_tables_from_postgres <- function() {
   src_postgres <- my_test_src()
   con_postgres <- src_postgres$con
 
-  dbGetQuery(con_postgres, "SELECT table_name FROM information_schema.tables WHERE table_schema = 'public'") %>%
+  con_postgres %>%
+    dbGetQuery("SELECT table_name FROM information_schema.tables WHERE table_schema = 'public'") %>%
     as_tibble() %>%
     filter(grepl("^tf_[0-9]{1}_[0-9]{4}_[0-9]{2}_[0-9]{2}_[0-9]{2}_[0-9]{2}_[0-9]{2}_[0-9]+", table_name))
 }
