@@ -1,3 +1,3 @@
 options(testthat.progress.verbose_skips = FALSE)
-options(Ncpus = parallel::detectCores())
+options(Ncpus = min(parallel::detectCores(), 12))
 options(tidyselect_verbosity = "verbose")
