@@ -24,7 +24,8 @@ test_that("table identifiers are quoted", {
     )
   )
 
-  dm <- suppress_mssql_warning(dm_from_src(src_db, learn_keys = FALSE)) %>%
+  dm <-
+    suppress_mssql_warning(dm_from_src(src_db, learn_keys = FALSE)) %>%
     dm_select_tbl(!!!remote_tbl_names_copied)
 
   remote_tbl_names_learned <-
@@ -82,9 +83,9 @@ test_that("copy_dm_to() and dm_from_src() output for compound keys", {
   withr::defer({
     walk(
       dm_get_tables_impl(nyc_comp_permanent)[c("flights", "airlines", "planes", "airports", "weather")],
-      ~ try(dbExecute(src_db$con, paste0("DROP TABLE ", dbplyr::remote_name(.x)))))
-    }
-  )
+      ~ try(dbExecute(src_db$con, paste0("DROP TABLE ", dbplyr::remote_name(.x))))
+    )
+  })
 
   expect_snapshot({
     learned_dm <- dm_from_src(src_db)[c("flights", "airlines", "planes", "airports", "weather")]
