@@ -1,14 +1,8 @@
 test_that("dm_add_fk() works as intended?", {
   expect_dm_error(
-    dm_add_fk(dm_test_obj(), dm_table_1, a, dm_table_4),
-    class = "ref_tbl_has_no_pk"
-  )
-
-  expect_true(
     dm_test_obj() %>%
-      dm_add_pk(dm_table_4, c) %>%
-      dm_add_fk(dm_table_1, a, dm_table_4) %>%
-      dm_has_fk(dm_table_1, dm_table_4)
+      dm_add_fk(dm_table_1, a, dm_table_4),
+    class = "ref_tbl_has_no_pk"
   )
 
   expect_dm_error(
@@ -18,9 +12,18 @@ test_that("dm_add_fk() works as intended?", {
       dm_add_fk(dm_table_1, a, dm_table_4),
     class = "fk_exists"
   )
+
+  expect_snapshot({
+    dm_test_obj() %>%
+      dm_add_pk(dm_table_4, c) %>%
+      dm_add_fk(dm_table_1, a, dm_table_4) %>%
+      get_all_keys()
+  })
 })
 
 test_that("dm_has_fk() and dm_get_fk() work as intended?", {
+  local_options(lifecycle_verbosity = "quiet")
+
   expect_identical(
     dm_test_obj() %>%
       dm_add_pk(dm_table_4, c) %>%
@@ -66,49 +69,40 @@ test_that("dm_has_fk() and dm_get_fk() work as intended?", {
 })
 
 test_that("dm_rm_fk() works as intended?", {
-  expect_true(
+  expect_silent(expect_true(
     dm_test_obj() %>%
       dm_add_pk(dm_table_4, c) %>%
       dm_add_fk(dm_table_1, a, dm_table_4) %>%
       dm_add_fk(dm_table_2, c, dm_table_4) %>%
       dm_rm_fk(dm_table_2, c, dm_table_4) %>%
-      dm_has_fk(dm_table_1, dm_table_4)
-  )
+      dm_has_fk_impl("dm_table_1", "dm_table_4")
+  ))
 
-  expect_false(
+  expect_silent(expect_false(
     dm_test_obj() %>%
       dm_add_pk(dm_table_4, c) %>%
       dm_add_fk(dm_table_1, a, dm_table_4) %>%
       dm_add_fk(dm_table_2, c, dm_table_4) %>%
       dm_rm_fk(dm_table_2, c, dm_table_4) %>%
-      dm_has_fk(dm_table_2, dm_table_4)
-  )
+      dm_has_fk_impl("dm_table_2", "dm_table_4")
+  ))
 
-  expect_false(
+  expect_message(expect_false(
     dm_test_obj() %>%
       dm_add_pk(dm_table_4, c) %>%
       dm_add_fk(dm_table_1, a, dm_table_4) %>%
       dm_add_fk(dm_table_2, c, dm_table_4) %>%
       dm_rm_fk(dm_table_2, NULL, dm_table_4) %>%
-      dm_has_fk(dm_table_2, dm_table_4)
-  )
+      dm_has_fk_impl("dm_table_2", "dm_table_4")
+  ))
 
   expect_dm_error(
-    dm_test_obj() %>%
-      dm_add_pk(dm_table_4, c) %>%
-      dm_add_fk(dm_table_1, a, dm_table_4) %>%
-      dm_add_fk(dm_table_2, c, dm_table_4) %>%
-      dm_rm_fk(table = dm_table_2, ref_table = dm_table_4),
-    class = "rm_fk_col_missing"
-  )
-
-  expect_error(
     dm_test_obj() %>%
       dm_add_pk(dm_table_4, c) %>%
       dm_add_fk(dm_table_1, a, dm_table_4) %>%
       dm_add_fk(dm_table_2, c, dm_table_4) %>%
       dm_rm_fk(dm_table_2, z, dm_table_4),
-    class = "vctrs_error_subscript_oob"
+    class = "is_not_fkc"
   )
 
   expect_dm_error(
@@ -119,6 +113,66 @@ test_that("dm_rm_fk() works as intended?", {
       dm_rm_fk(dm_table_2, c, dm_table_4),
     class = "is_not_fkc"
   )
+
+  # Bad input
+  expect_dm_error(
+    dm_for_filter() %>%
+      dm_rm_fk(tf_x),
+    class = "table_not_in_dm"
+  )
+
+  expect_dm_error(
+    dm_for_filter() %>%
+      dm_rm_fk(columns = x),
+    class = "is_not_fkc"
+  )
+
+  expect_dm_error(
+    dm_for_filter() %>%
+      dm_rm_fk(ref_table = tf_x),
+    class = "table_not_in_dm"
+  )
+
+  expect_dm_error(
+    dm_for_filter() %>%
+      dm_rm_fk(ref_columns = x),
+    class = "is_not_fkc"
+  )
+})
+
+
+test_that("dm_rm_fk() works with partial matching", {
+  expect_snapshot({
+    # Only table
+    dm_for_filter() %>%
+      dm_rm_fk(tf_5) %>%
+      get_all_keys()
+
+    # Only columns
+    dm_for_filter() %>%
+      dm_rm_fk(columns = l) %>%
+      get_all_keys()
+
+    # Only columns, compound
+    dm_for_filter() %>%
+      dm_rm_fk(columns = c(e, e1)) %>%
+      get_all_keys()
+
+    # Only ref_table
+    dm_for_filter() %>%
+      dm_rm_fk(ref_table = tf_3) %>%
+      get_all_keys()
+
+    # Only ref_columns, compound
+    dm_for_filter() %>%
+      dm_rm_fk(ref_columns = c(f, f1)) %>%
+      get_all_keys()
+
+    # All foreign keys
+    dm_for_filter() %>%
+      dm_rm_fk() %>%
+      get_all_keys()
+  })
 })
 
 
@@ -150,7 +204,8 @@ test_that("dm_enum_fk_candidates() works as intended?", {
     mutate(columns = new_keys(columns))
 
   expect_identical(
-    dm_add_pk(dm_test_obj_2(), dm_table_4, c) %>%
+    dm_test_obj_2() %>%
+      dm_add_pk(dm_table_4, c) %>%
       dm_enum_fk_candidates(dm_table_3, dm_table_4) %>%
       mutate(why = if_else(why != "", "<reason>", "")),
     tbl_tf_3_tf_4
@@ -177,52 +232,19 @@ test_that("dm_enum_fk_candidates() works as intended?", {
 
   skip_if_not_installed("nycflights13")
 
-  nycflights_example <- tibble::tribble(
-    ~column,     ~candidate,       ~why,
-    "origin",          TRUE,         "",
-    "year",           FALSE, "<reason>",
-    "month",          FALSE, "<reason>",
-    "day",            FALSE, "<reason>",
-    "dep_time",       FALSE, "<reason>",
-    "sched_dep_time", FALSE, "<reason>",
-    "dep_delay",      FALSE, "<reason>",
-    "arr_time",       FALSE, "<reason>",
-    "sched_arr_time", FALSE, "<reason>",
-    "arr_delay",      FALSE, "<reason>",
-    "carrier",        FALSE, "<reason>",
-    "flight",         FALSE, "<reason>",
-    "tailnum",        FALSE, "<reason>",
-    "dest",           FALSE, "<reason>",
-    "air_time",       FALSE, "<reason>",
-    "distance",       FALSE, "<reason>",
-    "hour",           FALSE, "<reason>",
-    "minute",         FALSE, "<reason>",
-    "time_hour",      FALSE, "<reason>",
-  ) %>%
-    rename(columns = column) %>%
-    mutate(columns = new_keys(columns))
-
-  expect_identical(
-    dm_enum_fk_candidates(dm_nycflights13(), flights, airports) %>%
-      mutate(why = if_else(why != "", "<reason>", "")),
-    nycflights_example
-  )
+  expect_snapshot({
+    dm_nycflights13() %>%
+      dm_enum_fk_candidates(flights, airports) %>%
+      mutate(why = if_else(why != "", "<reason>", ""))
+  })
 })
 
 test_that("enum_fk_candidates() works properly", {
+  # FIXME: COMPOUND: Test for tf_2 -> tf_3 and other combinations too
   expect_silent(
     expect_equivalent_why(
-      enum_fk_candidates(zoomed_dm(), tf_3),
-      dm_enum_fk_candidates(dm_for_filter(), tf_2, tf_3)
+      enum_fk_candidates(zoomed_dm(), tf_1),
+      dm_enum_fk_candidates(dm_for_filter(), tf_2, tf_1)
     )
   )
 })
-
-# tests for compound keys -------------------------------------------------
-
-test_that("dm_get_all_fks() with compound keys", {
-  expect_snapshot({
-    nyc_comp() %>%
-      dm_get_all_fks()
-  })
-})
