@@ -6,10 +6,10 @@ test_that("'nest_join_zoomed_dm()'-method for `zoomed_dm` works", {
       nest_join_zoomed_dm() %>%
       pull_tbl(),
     tf_3() %>%
-      nest_join(tf_2(), name = "tf_2", by = c("f" = "e")) %>%
-      mutate(tf_2 = vctrs::as_list_of(tf_2)) %>%
+      nest_join(tf_2(), name = "tf_2", by = c("f" = "e", "f1" = "e1")) %>%
+      mutate(tf_2 = as_list_of(tf_2)) %>%
       nest_join(tf_4(), name = "tf_4", by = c("f" = "j")) %>%
-      mutate(tf_4 = vctrs::as_list_of(tf_4))
+      mutate(tf_4 = as_list_of(tf_4))
   )
 
   expect_equivalent_tbl(
@@ -18,9 +18,9 @@ test_that("'nest_join_zoomed_dm()'-method for `zoomed_dm` works", {
       pull_tbl(),
     tf_3() %>%
       nest_join(tf_4(), name = "tf_4", by = c("f" = "j")) %>%
-      mutate(tf_4 = vctrs::as_list_of(tf_4)) %>%
-      nest_join(tf_2(), name = "tf_2", by = c("f" = "e")) %>%
-      mutate(tf_2 = vctrs::as_list_of(tf_2))
+      mutate(tf_4 = as_list_of(tf_4)) %>%
+      nest_join(tf_2(), name = "tf_2", by = c("f" = "e", "f1" = "e1")) %>%
+      mutate(tf_2 = as_list_of(tf_2))
   )
 
   expect_message(
